@@ -2,7 +2,7 @@ mod utils;
 
 #[cfg(test)]
 mod trade {
-    use crypto_msg_parser::{parse_trade, MarketType, TradeSide};
+    use crypto_msg_parser::{extract_symbol, parse_trade, MarketType, TradeSide};
     use float_cmp::approx_eq;
 
     #[test]
@@ -13,7 +13,13 @@ mod trade {
         assert_eq!(trades.len(), 1);
         let trade = &trades[0];
 
-        crate::utils::check_trade_fields("kucoin", MarketType::Spot, "BTC/USDT".to_string(), trade);
+        crate::utils::check_trade_fields(
+            "kucoin",
+            MarketType::Spot,
+            "BTC/USDT".to_string(),
+            extract_symbol("kucoin", MarketType::Spot, raw_msg).unwrap(),
+            trade,
+        );
 
         assert_eq!(trade.quantity_base, 0.00013064);
         assert_eq!(trade.quantity_contract, None);
@@ -32,6 +38,7 @@ mod trade {
             "kucoin",
             MarketType::LinearSwap,
             "BTC/USDT".to_string(),
+            extract_symbol("kucoin", MarketType::LinearSwap, raw_msg).unwrap(),
             trade,
         );
 
@@ -63,6 +70,7 @@ mod trade {
             "kucoin",
             MarketType::InverseSwap,
             "BTC/USD".to_string(),
+            extract_symbol("kucoin", MarketType::InverseSwap, raw_msg).unwrap(),
             trade,
         );
 
@@ -84,6 +92,7 @@ mod trade {
             "kucoin",
             MarketType::InverseFuture,
             "BTC/USD".to_string(),
+            extract_symbol("kucoin", MarketType::InverseFuture, raw_msg).unwrap(),
             trade,
         );
 
@@ -96,7 +105,7 @@ mod trade {
 
 #[cfg(test)]
 mod l2_orderbook {
-    use crypto_msg_parser::{parse_l2, MarketType};
+    use crypto_msg_parser::{extract_symbol, parse_l2, MarketType};
 
     #[test]
     fn spot_update() {
@@ -112,6 +121,7 @@ mod l2_orderbook {
             "kucoin",
             MarketType::Spot,
             "BTC/USDT".to_string(),
+            extract_symbol("kucoin", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -133,6 +143,7 @@ mod l2_orderbook {
             "kucoin",
             MarketType::InverseSwap,
             "BTC/USD".to_string(),
+            extract_symbol("kucoin", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -157,6 +168,7 @@ mod l2_orderbook {
             "kucoin",
             MarketType::LinearSwap,
             "BTC/USDT".to_string(),
+            extract_symbol("kucoin", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -181,6 +193,7 @@ mod l2_orderbook {
             "kucoin",
             MarketType::InverseFuture,
             "BTC/USD".to_string(),
+            extract_symbol("kucoin", MarketType::InverseFuture, raw_msg).unwrap(),
             orderbook,
         );
 
